/*
	Author: Kanad Mehta | Incepto | kanad@incepto.com.au
	Purpose: Get value of prescribed column from JSON string.
	Note: If your database has compatibility level of 130 or more then OpenJSON is a better alternative.
	To View/ Change compatibility level: https://docs.microsoft.com/en-us/sql/relational-databases/databases/view-or-change-the-compatibility-level-of-a-database
	About OpenJSON: https://docs.microsoft.com/en-us/sql/t-sql/functions/openjson-transact-sql
*/

CREATE FUNCTION Get_JSON_Value
(
    @JSON NVARCHAR(4000),
    @column NVARCHAR(100)
)
RETURNS NVARCHAR(4000)
AS
BEGIN

	DECLARE @value NVARCHAR(4000);
	DECLARE @trimmedJSON NVARCHAR(4000);

	DECLARE @start INT;
	DECLARE @end INT;

	SET @start = PATINDEX('%"' + @column + '":%',@JSON) + LEN(@column) + 2;
	SET @trimmedJSON = SUBSTRING(@JSON, @start, LEN(@JSON));
	SET @end = CHARINDEX(',',@trimmedJSON);
	IF @end = 0
	BEGIN
		Set @end = CHARINDEX('}',@trimmedJSON)
	END

	SET @value = REPLACE(SUBSTRING(@trimmedJSON, 0, @end),'"','');
	SET @value = LTRIM(@value);
	SET @value = RTRIM(@value);

	IF LEFT(@value, 1)=':'
	BEGIN
		SET @value = STUFF(@value,1,1,'')
	END

	RETURN @value
END
GO